@@ -1,3 +1,11 @@
+/*
+Portions Copyright 2019-2021 ZomboDB, LLC.
+Portions Copyright 2021-2022 Technology Concepts & Design, Inc. <support@tcdi.com>
+
+All rights reserved.
+
+Use of this source code is governed by the MIT license that can be found in the LICENSE file.
+*/
 use proc_macro2::TokenStream as TokenStream2;
 use quote::{quote, ToTokens, TokenStreamExt};
 use syn::parse::{Parse, ParseBuffer};
@@ -27,12 +35,12 @@ impl ToTokens for PgOperator {
         let hashes = self.hashes;
         let merges = self.merges;
         let quoted = quote! {
-            pgx::datum::sql_entity_graph::PgOperatorEntity {
-                opname: None#( .unwrap_or(Some(#opname)) )*,
-                commutator: None#( .unwrap_or(Some(#commutator)) )*,
-                negator: None#( .unwrap_or(Some(#negator)) )*,
-                restrict: None#( .unwrap_or(Some(#restrict)) )*,
-                join: None#( .unwrap_or(Some(#join)) )*,
+            ::pgx::utils::sql_entity_graph::PgOperatorEntity {
+                opname: None #( .unwrap_or(Some(#opname)) )*,
+                commutator: None #( .unwrap_or(Some(#commutator)) )*,
+                negator: None #( .unwrap_or(Some(#negator)) )*,
+                restrict: None #( .unwrap_or(Some(#restrict)) )*,
+                join: None #( .unwrap_or(Some(#join)) )*,
                 hashes: #hashes,
                 merges: #merges,
             }
